#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store
version:              0.7.20
visibility:           public
id:                   store-0.7.20-66CJoOahiXMCZ09H2hVF01
key:                  store-0.7.20-66CJoOahiXMCZ09H2hVF01
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/mgsloan/store#readme
synopsis:             Fast binary serialization
category:             Serialization, Data
abi:                  a6885db4b3321d4541683678a3fe17aa
exposed:              True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer

hidden-modules:       Data.Store.Impl
import-dirs:          /usr/lib/ghc-9.6.6/site-local/store-0.7.20
library-dirs:         /usr/lib/ghc-9.6.6/site-local/store-0.7.20
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/store-0.7.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store
hs-libraries:         HSstore-0.7.20-66CJoOahiXMCZ09H2hVF01
depends:
    array-0.5.6.0 async-2.2.6-ITRC11Ox8a3Q3zDt3UwKf base-4.18.2.1
    base-orphans-0.9.4-8nMYCrW1BfT8fcuDowN3b3
    base64-bytestring-1.2.1.0-3MnxOO7xl0P127Exi8mxw2
    bifunctors-5.6.3-40xKQKgYXzc6u9JTwdJvAF bytestring-0.11.5.3
    containers-0.6.7 contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha1-0.11.101.0-FicrQGbdqQGEupCfHibC0e deepseq-1.4.8.1
    directory-1.3.8.5 filepath-1.4.300.1
    free-5.2-IPqfEFGY8zS5f5J8nSZGaF ghc-prim-0.10.0
    hashable-1.4.7.0-Ws19qMM2f99bApawlWBTg
    hspec-2.11.7-DlmsZFIl5t8722t58ZW2or
    hspec-smallcheck-0.5.3-8G7GvAe6k1X2nY0rjeTVWl integer-gmp-1.1
    lifted-base-0.2.3.12-t6zvs0m7o6IP4mH5tvmLv
    monad-control-1.0.3.1-E5lxYdZ2T24L5KA6ZxZqUG
    mono-traversable-1.0.21.0-IH4LsBNMWXUK6f4IHiqLkH
    network-3.1.4.0-Ds5DY5mKlnsDQk8HC4tJQL
    primitive-0.9.1.0-J2dxudhiRepI2JRXVzckXt
    resourcet-1.3.0-Cuj4zJihfYr1ci2ntaM4ld
    safe-0.3.21-KdE8f1g6p6v53Pxmzg6oHI
    smallcheck-1.2.1.1-Eg6ovITj5b8CEsH2BpEOln
    store-core-0.4.4.7-JHN4HtPKZPj1iqfD5MckOx
    syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.7-JMijAGUD56uaCh66C6Lgg
    th-lift-instances-0.1.20-JZQs0SgR0NF8iOjWUtJL87
    th-orphans-0.13.17-Jls3Z8ur1RWF621LURh9bK
    th-reify-many-0.1.10-3nEZfG4JrET7STF9qM5wsn
    th-utilities-0.2.5.2-4yqXanckfq6LYDQzkhKUMu time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP
    vector-0.13.2.0-KNP2q6eDEp8AmnRr9wgHHB
    void-0.7.4-Ab78HEYVlxC2PerDGXO6Wd

haddock-interfaces:   /usr/share/doc/haskell-store/html/store.haddock
haddock-html:         /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

